#!/usr/local/bin/perl5 asp

<!--#include file=header.inc-->
        For loop decrementing font size: <p>
        <% for(reverse(1..6)) { %>
                <!-- iterated html text -->
                <font size="<%=$_%>" > Size = <%=$_%> </font> <br>
        <% } %>
<!--#include file=footer.inc-->

